# Generated by Django 2.2.23 on 2021-07-29 17:12

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_notification', '0011_auto_20210218_1145'),
    ]

    operations = [
        migrations.AlterField(
            model_name='notification',
            name='summary',
            field=models.TextField(blank=True, default=''),
        ),
    ]
