# Generated by Django 2.2.23 on 2021-10-16 10:03

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import djangoldp.fields


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_notification', '0012_auto_20210729_1912'),
    ]

    operations = [
        migrations.AlterField(
            model_name='notification',
            name='author',
            field=djangoldp.fields.LDPUrlField(help_text='the sender of the notification'),
        ),
        migrations.AlterField(
            model_name='notification',
            name='object',
            field=djangoldp.fields.LDPUrlField(help_text='the urlid of the saved object being transmitted by the notification'),
        ),
        migrations.AlterField(
            model_name='notification',
            name='unread',
            field=models.BooleanField(default=True, help_text='set to False after the user has seen the notification'),
        ),
        migrations.AlterField(
            model_name='notification',
            name='user',
            field=models.ForeignKey(help_text='the recipient of the notification', on_delete=django.db.models.deletion.CASCADE, related_name='inbox', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='notificationsetting',
            name='receiveMail',
            field=models.BooleanField(default=True, help_text='if set to True the user will receive an email on notification receipt'),
        ),
        migrations.AlterField(
            model_name='subscription',
            name='inbox',
            field=models.URLField(help_text='the inbox of the recipient of the notification'),
        ),
        migrations.AlterField(
            model_name='subscription',
            name='object',
            field=models.URLField(help_text='the urlid of the object being subscribed'),
        ),
    ]
